package MT::Plugin::Print;

use strict;
use base qw( MT::Plugin );
our $VERSION = '1.0'; 

my $plugin = MT::Plugin::Print->new({
   id          => 'print_cssj',
   key         => 'print-cssj',
   name        => 'ブログ出版局',
   description => "ブログ出版局でブログを書籍化出来ます。",
   version     => $VERSION,
   author_name => "ブログ出版局",
   author_link => "http://print.cssj.jp/",
   plugin_link => "http://blog.print.cssj.jp/index.php?itemid=124",
});
MT->add_plugin($plugin);

sub init_registry {
    my $plugin = shift;
    $plugin->registry({
        applications => {
            'cms' => {
                methods => {
                    print => '$print_cssj_jp::MT::Plugin::Print::do_print'
                },
            },
        },
        
        callbacks => {
            # エクスポートページを修正
            'MT::App::CMS::template_source.export' => sub { $plugin->add_print(@_); }
        }
    });
}

sub do_print {
    my $app = shift;
    $app->{no_print_body} = 1;
    local $| = 1;
    require MT::Blog;
    my $blog_id = $app->param('blog_id')
      or return $app->error( $app->translate("Please select a blog.") );
    my $blog = MT::Blog->load($blog_id)
      or return $app->error(
        $app->translate(
            "Load of blog '[_1]' failed: [_2]",
            $blog_id, MT::Blog->errstr
        )
      );
    my $perms = $app->permissions;
    return $app->error( $app->translate("You do not have export permissions") )
      unless $perms && $perms->can_edit_config;
    $app->validate_magic() or return;
    
    require File::Temp;
    my ($fh, $data_file) = File::Temp::tempfile();
    require MT::ImportExport;
    MT::ImportExport->export( $blog, sub { CORE::print $fh @_; } )
        or return $app->error( MT::ImportExport->errstr );
    close($fh);
    
    my %params = (
        'encoding' => $app->charset,
        'uri' => $blog->site_url,
        'title' => $blog->name,
        'author' => $app->user->nickname,
        'mail_address' => $app->user->email,
        'return' => 'http://cgi.port4.info/mt401/mt.cgi?__mode=start_export&blog_id=1',
        'data_file' => [$data_file]
    );
    require PrintCSSJ;
    my %result =  PrintCSSJ::do_upload(\%params) or
        return $app->error('接続エラー');
    if ($result{'error'} == 1)
    {
        return $app->error($result{'message'});
    }
    $app->redirect($result{'redirect'});
    1;
}

sub add_print {
    my $plugin = shift;
    my ($cb, $app, $tmpl) = @_;
    my $old = <<HTML;
    <button
        type="submit"
        accesskey="s"
        title="<__trans phrase="Export Blog (s)">"
        class="primary-button"
        ><__trans phrase="Export Blog"></button>
HTML
                my $add = <<HTML;
    <button
        type="submit"
        accesskey="s"
        title="<__trans phrase="Export Blog (s)">"
        class="primary-button"
        onclick="this.form.elements.__mode.value='export'"
        ><__trans phrase="Export Blog"></button>
    <button
        type="submit"
        accesskey="p"
        title="ブログ出版局で本にする"
        class="primary-button"
        onclick="this.form.target='_blank';this.form.elements.__mode.value='print'"
        >ブログ出版局で本にする</button>
HTML
    $old = quotemeta ($old);
    $$tmpl =~ s/($old)/$add/;
}